@@ -1,27 +1,25 @@
 import os
 import re
-import subprocess
 from pathlib import Path
 
 import chevron
 import markdown
-from markdownup.filesystem.entry import Entry
+
 from markdownup.filesystem.file import File
 from markdownup.response import Response
 
 
-class MarkdownFile(Entry, File):
+class MarkdownFile(File):
 
     _title_pattern = re.compile(r'^#\s?(.*)', re.MULTILINE)
     _search_term_pattern = re.compile(r'\w{2,}')
 
-    def __init__(self, context, path: Path, depth: int):
+    def __init__(self, context, path: Path):
 
-        super().__init__(context, path, depth)
+        super().__init__(context, path)
 
         self.name = self._get_title(path.read_text()) or self.name
-        self.request_path = '/' + '/'.join(path.parts[len(path.parts) - depth - 1:])
-        self.version = self._get_version_details()
+        self.request_path = f'/{path.relative_to(self.context.root_path)}'
         self.search_index = self._get_search_index()
         self.cache_mode = self.config.get('markdown', 'cache')
         self.cache_value = None
@@ -84,46 +82,6 @@ class MarkdownFile(Entry, File):
         match = MarkdownFile._title_pattern.search(md)
         return match.group(1) if match else None
 
-    def _get_version_details(self):
-
-        # define the cwd and arg for the git call assuming .git is not external
-        cwd = self.path.parent
-        arg = self.path.name
-
-        # update cwd and arg if we match a configured external .git
-        root = self.context.root_path
-        relative = self.path.relative_to(root)
-        for root_path, git_path in self.config.get('content', 'gits').items():
-            try:
-                possible_arg = relative.relative_to(root_path)
-                cwd = git_path
-                arg = possible_arg
-                break
-            except ValueError:
-                pass
-
-        result = subprocess.run(
-            ['git', 'log', '-1', '--format=%an%n%ae%n%cI%n%h%n%H', '--', arg],
-            cwd=cwd,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.DEVNULL
-        )
-        if result.returncode == 0:
-            lines = result.stdout.decode('UTF-8').splitlines()
-            if lines:
-                return {
-                    'author': {
-                        'name': lines[0],
-                        'email': lines[1]
-                    },
-                    'date': lines[2],
-                    'short_hash': lines[3],
-                    'hash': lines[4]
-                }
-            return lines
-        else:
-            return None
-
     def _get_search_index(self):
         search_index = {}
         haystack = self.path.read_text()
