@@ -39,10 +39,13 @@ def get_search_response(context, environ, request):
             'search_terms': search_terms,
             'search_results': search_results
         }
-    )
+    ).encode('UTF-8')
 
     return Response(
         '200 OK',
-        [('Content-Type', 'text/html')],
-        (bytes(b, 'UTF-8') for b in html.splitlines(keepends=True))
+        [
+            ('Content-Type', 'text/html; charset=utf-8'),
+            ('Content-Length', str(len(html)))
+        ],
+        [html]
     )
